scaled_eq_ind_partial_eval

Function scaled_eq_ind_partial_eval 

pub fn scaled_eq_ind_partial_eval<P: PackedField>(
    point: &[P::Scalar],
    scale: P::Scalar,
) -> FieldBuffer<P>
Computes the partial evaluation of the equality indicator polynomial, scaled by a constant.

Every hypercube value of the equality indicator is multiplied by the scale. A scale of one is the identity, since the expansion is linear in it.

Arguments

  • point - The evaluation point whose length is the number of variables.
  • scale - The constant every returned value is multiplied by.